==> nextcloud-app-mail-4.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/br.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Postel pouezus",
    "Set up an account" : "Staliañ ur c'hont",
    "Work" : "Labour",
    "Personal" : "Personel",
    "Mail" : "Postel",
    "Name" : "Anv",
    "Password" : "Ger-tremen",
    "None" : "Hini ebet",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Ger-tremen SMTP",
    "Save" : "Enrollañ",
    "Connect" : "Kenstagañ",
    "Password required" : "Ger-tremen ret",
    "Change name" : "Cheñch env",
    "Cancel" : "Arrest",
    "Accounts" : "Kontoù",
    "General" : "Hollek",
    "List" : "Roll",
    "Delete" : "Dilemel",
    "Search" : "Klask",
    "Send" : "Kas",
    "Refresh" : "Freskaat",
    "Choose" : "Dibab",
    "Confirm" : "Kadarnañ",
    "Unfavorite" : "Digaretañ",
    "Favorite" : "Pennrollañ",
    "Unselect" : "Dizibab",
    "Select" : "Dibab",
    "Back" : "Distro",
    "Forward" : "War-raok",
    "Description" : "Deskrivadur",
    "Create" : "Krouiñ",
    "Comment" : "Displegadenn",
    "Accept" : "Asantiñ",
    "Remove" : "Lemel",
    "email" : "postel",
    "Important info" : "Titouroù pouezus",
    "Other" : "All",
    "Show images" : "Diskouzh ar skeudennoù",
    "Message frame" : "Fram kemenadenn",
    "Move" : "Diplasañ",
    "Quota" : "Quota",
    "Remove account" : "Lemel ar c'hont",
    "Loading …" : "O Kargañ ...",
    "Rename" : "Adenvel",
    "Clear cache" : "Gwalc'hiñ ar c'hache",
    "Retry" : "Klaskit en dro",
    "Reply" : "Respont",
    "Add" : "Ouzhpennañ",
    "Close" : "Serriñ",
    "Date" : "Deiz",
    "Tags" : "Klavioù",
    "Clear" : "Netaat",
    "Actions" : "Oberoù",
    "Client ID" : "ID kliant",
    "User" : "Implijer",
    "Host" : "Ostiz",
    "Port" : "Porzh",
    "Valid until" : "Gwir betek",
    "Submit" : "Kinnig",
    "Account connected" : "Kont kenstaged",
    "All" : "Pep tra",
    "Favorites" : "Pennrolloù",
    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-app-mail-4.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/br.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Postel pouezus",
    "Set up an account" : "Staliañ ur c'hont",
    "Work" : "Labour",
    "Personal" : "Personel",
    "Mail" : "Postel",
    "Name" : "Anv",
    "Password" : "Ger-tremen",
    "None" : "Hini ebet",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Ger-tremen SMTP",
    "Save" : "Enrollañ",
    "Connect" : "Kenstagañ",
    "Password required" : "Ger-tremen ret",
    "Change name" : "Cheñch env",
    "Cancel" : "Arrest",
    "Accounts" : "Kontoù",
    "General" : "Hollek",
    "List" : "Roll",
    "Delete" : "Dilemel",
    "Search" : "Klask",
    "Send" : "Kas",
    "Refresh" : "Freskaat",
    "Choose" : "Dibab",
    "Confirm" : "Kadarnañ",
    "Unfavorite" : "Digaretañ",
    "Favorite" : "Pennrollañ",
    "Back" : "Distro",
    "Description" : "Deskrivadur",
    "Create" : "Krouiñ",
    "Select" : "Dibab",
    "Comment" : "Displegadenn",
    "Accept" : "Asantiñ",
    "Remove" : "Lemel",
    "email" : "postel",
    "Important info" : "Titouroù pouezus",
    "Other" : "All",
    "Forward" : "War-raok",
    "Translate" : "Treiñ",
    "Show images" : "Diskouzh ar skeudennoù",
    "Message frame" : "Fram kemenadenn",
    "Move" : "Diplasañ",
    "Quota" : "Quota",
    "Remove account" : "Lemel ar c'hont",
    "Loading …" : "O Kargañ ...",
    "Rename" : "Adenvel",
    "Clear cache" : "Gwalc'hiñ ar c'hache",
    "Retry" : "Klaskit en dro",
    "Reply" : "Respont",
    "Add" : "Ouzhpennañ",
    "Close" : "Serriñ",
    "Date" : "Deiz",
    "Tags" : "Klavioù",
    "Clear" : "Netaat",
    "Actions" : "Oberoù",
    "Client ID" : "ID kliant",
    "User" : "Implijer",
    "Host" : "Ostiz",
    "Port" : "Porzh",
    "Valid until" : "Gwir betek",
    "Submit" : "Kinnig",
    "Account connected" : "Kont kenstaged",
    "All" : "Pep tra",
    "Favorites" : "Pennrolloù",
    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
    "Unselect" : "Dizibab"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
